#-----------------------------------------------------------------------------
%{?!dist:	%define	dist	.ok}
%define		sname		udev
%define		lfsvers		20230818
#-----------------------------------------------------------------------------
Name		:	systemd
Version		:	254
Release		:	14.4.0.0%{?dist}
Summary		:	Udev from Systemd

Packager	:	Osukiss Project	<build-ok@osukiss.org>

License		:	GPLv2+
URL		:	https://www.freedesktop.org/wiki/Software/systemd/

Source0		:	%{name}-%{version}.tar.gz
Source1		:	%{name}-man-pages-%{version}.tar.xz
Source2		:	udev-lfs-%{lfsvers}.tar.xz
Source3		:	%{name}-ok_addon.tar.gz
#-----------------------------------------------------------------------------
Buildrequires	:	kmod
Buildrequires	:	util-linux
Buildrequires	:	xz-devel
Buildrequires	:	python3-Jinja2

Requires(pre)	:	kmod,util-linux
#-----------------------------------------------------------------------------
%description
Starting with the 2.5 kernel, all physical and virtual devices in a
system are visible to userspace in a hierarchal fashion through
sysfs. /sbin/hotplug provides a notification to userspace when any
device is added or removed from the system. Using these two features,
a userspace implementation of a dynamic /dev is now possible that can
provide a very flexible device naming policy

%files
%defattr(-,root,root,-)
%doc README README.md
#=============================================================================
%package		-n e%{sname}
Summary		:	file to access udev device information

#-----------------------------------------------------------------------------
%description		-n e%{sname} 
This package provides binary to access eudev device information

#-----------------------------------------------------------------------------
%files			-n e%{sname}
%defattr(-,root,root,-)
%{_bindir}/%{sname}adm
%{_bindir}/%{sname}-hwdb
%{_sbindir}/%{sname}d
%{_sysconfdir}/%{sname}/%{sname}.conf
%{_sysconfdir}/%{sname}/rules.d/*.rules
%{_sysconfdir}/rc.d/init.d/%{sname}
%{_sysconfdir}/rc.d/rcS.d/S10%{sname}
%dir %{_sysconfdir}/%{sname}/hwdb.d
%{_libdir}/%{sname}/ata_id
%{_libdir}/%{sname}/cdrom_id
%{_libdir}/%{sname}/dmi_memory_id
%{_libdir}/%{sname}/fido_id
%{_libdir}/%{sname}/iocost
%{_libdir}/%{sname}/mtd_probe
%{_libdir}/%{sname}/scsi_id
%{_libdir}/%{sname}/v4l_id
%{_libdir}/%{sname}/rules.d/README
%{_libdir}/%{sname}/rules.d/*.rules
%{_libdir}/%{sname}/hwdb.d/README
%{_libdir}/%{sname}/hwdb.d/[1-9]0-*.hwdb
%{_libdir}/%{sname}/init-net-rules.sh
%{_libdir}/%{sname}/rule_generator.functions
%{_libdir}/%{sname}/write_net_rules
%{_defaultdocdir}/%{sname}-%{lfsvers}/*
%{_mandir}/man5/%{sname}.conf.5.gz
%{_mandir}/man7/%{sname}.7.gz
%{_mandir}/man8/%{sname}*.8.gz


#-----------------------------------------------------------------------------
%post			-n e%{sname}
#to take care of new hardware definition
%{_bindir}/%{sname}-hwdb update


#=============================================================================
%package		-n e%{sname}-libs
Summary		:	Shared library to access udev device information

#-----------------------------------------------------------------------------
%description		-n e%{sname}-libs 
This package provides shared library to access eudev device information

#-----------------------------------------------------------------------------
%files			-n e%{sname}-libs
%defattr(-,root,root,-)
%{_libdir}/lib%{sname}.so.1*

#=============================================================================
%package		-n e%{sname}-devel
Summary		:	Development libraries for eudev

#-----------------------------------------------------------------------------
Requires	:	e%{sname}-libs = %{version}-%{release}

#-----------------------------------------------------------------------------
%description		-n e%{sname}-devel 
Header and Library files for doing development with the eudev.

#-----------------------------------------------------------------------------
%files			-n e%{sname}-devel
%defattr(-,root,root,-)
%{_includedir}/libudev.h 
%{_libdir}/lib%{sname}.so
%{_libdir}/pkgconfig/lib%{sname}.pc
%{_datadir}/pkgconfig/%{sname}.pc

#=============================================================================
%prep
%setup -q
tar xf %{SOURCE1}
tar xf %{SOURCE2}
tar xf %{SOURCE3}

#Remove two unneeded groups, render and sgx,
#from the default udev rules:

sed -i								\
  -e 's/GROUP="render"/GROUP="video"/'				\
  -e 's/GROUP="sgx", //'					\
  rules.d/50-udev-default.rules.in

#Remove one udev rule requiring a full Systemd installation:
sed -i								\
  -e '/systemd-sysctl/s/^/#/'					\
  rules.d/99-systemd.rules.in



#-----------------------------------------------------------------------------
#building application
%build

#Prepare Udev for compilation:
meson setup							\
	--prefix=%{_prefix}					\
	--buildtype=release					\
	-D mode=release						\
	-D dev-kvm-mode=0660					\
	-D link-udev-shared=false				\
	_bld							\

pushd	_bld	> /dev/null
ninja								\
	udevadm							\
	systemd-hwdb						\
	$(grep -o -E 						\
	  "^build (src/libudev|src/udev|rules.d|hwdb.d)[^:]*"	\
          build.ninja | awk '{ print $2 }')			\
	$(realpath libudev.so --relative-to .)

#Remove one udev rule file requiring a full Systemd installation
rm								\
	rules.d/90-vconsole.rules

popd

#-----------------------------------------------------------------------------
%clean
%{__rm} -rf %{buildroot}

#-----------------------------------------------------------------------------
#installing program
%install
%{__rm} -rf %{buildroot}

%{__make}							\
        -f udev-lfs-%{lfsvers}/Makefile.lfs			\
        DESTDIR=%{buildroot}					\
        install

#installing udev part of systemd
pushd	_bld	> /dev/null
install -m755 -d %{buildroot}%{_bindir}
install -m755 							\
	%{sname}adm						\
	%{buildroot}%{_bindir}

install -m755 							\
	systemd-hwdb						\
	%{buildroot}%{_bindir}/%{sname}-hwdb

install -m755 -d %{buildroot}%{_sbindir}
%{__ln_s}							\
	../bin/%{sname}adm					\
	%{buildroot}%{_sbindir}/%{sname}d
	
install -m755 -d %{buildroot}%{_libdir}/pkgconfig
install -m644 							\
	./src/libudev/*.pc					\
	%{buildroot}%{_libdir}/pkgconfig/
cp      -a							\
	libudev.so{,*[0-9]}  					\
	%{buildroot}%{_libdir}

install -m755 -d %{buildroot}%{_datadir}/pkgconfig
install -m644 							\
	./src/udev/*.pc						\
	%{buildroot}%{_datadir}/pkgconfig/

install -m755 -d %{buildroot}%{_includedir}
install -m644							\
	../src/libudev/libudev.h				\
	%{buildroot}%{_includedir}/

install -m755 -d %{buildroot}%{_libdir}/%{sname}/rules.d/
install -m644							\
	rules.d/* 						\
	../rules.d/{*.rules,README}				\
	%{buildroot}%{_libdir}/%{sname}/rules.d/

install -m755 -d %{buildroot}%{_sysconfdir}/%{sname}/hwdb.d
install -m755 -d %{buildroot}%{_libdir}/%{sname}/hwdb.d
install -m644							\
	hwdb.d/* 						\
	../hwdb.d/{*.hwdb,README}				\
	 %{buildroot}%{_libdir}/%{sname}/hwdb.d

install -m755 -d %{buildroot}%{_sysconfdir}/%{sname}/
install -m644							\
	../src/%{sname}/%{sname}.conf				\
	%{buildroot}%{_sysconfdir}/%{sname}/

install -m755 							\
	$(find src/udev -type f | grep -F -v ".")		\
	%{buildroot}%{_libdir}/%{sname}/

popd

#installing manual
install -m755 -d %{buildroot}%{_mandir}/{man5,man7,man8}

%{__cp} -a							\
	%{name}-man-pages-%{version}/man5/%{sname}.conf.5	\
	%{buildroot}%{_mandir}/man5/
%{__cp} -a							\
	%{name}-man-pages-%{version}/man7/%{sname}.7		\
	%{buildroot}%{_mandir}/man7/
%{__cp} -a							\
	%{name}-man-pages-%{version}/man8/%{sname}adm.8		\
	%{buildroot}%{_mandir}/man8/
sed 								\
 -e 's|lib.*udevd|sbin/udevd|'					\
 %{name}-man-pages-%{version}/man8/%{name}-%{sname}d.service.8	\
 > %{buildroot}%{_mandir}/man8/%{sname}.8

#setup init file 
%{__mkdir_p}							\
	%{buildroot}%{_sysconfdir}/rc.d/init.d			\
	%{buildroot}%{_sysconfdir}/rc.d/rcS.d
%{__cp} -a							\
	%{name}-ok_addon/%{sname}.init				\
	%{buildroot}%{_sysconfdir}/rc.d/init.d/%{sname}
%{__ln_s}							\
	../init.d/%{sname}					\
	%{buildroot}%{_sysconfdir}/rc.d/rcS.d/S10%{sname}

	
#-----------------------------------------------------------------------------
%changelog
